==> agrosyst-web-0.4.1-sources.jar: fr/inra/agrosyst/web/actions/growingplans/GrowingPlansDuplicate.java <==
package fr.inra.agrosyst.web.actions.growingplans;

/*
 * #%L
 * Agrosyst :: Web
 * $Id: GrowingPlansDuplicate.java 928 2013-08-13 09:26:31Z echatellier $
 * $HeadURL: https://forge.codelutin.com/svn/agrosyst/tags/agrosyst-0.4.1/agrosyst-web/src/main/java/fr/inra/agrosyst/web/actions/growingplans/GrowingPlansDuplicate.java $
 * %%
 * Copyright (C) 2013 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import org.apache.struts2.convention.annotation.Action;
import org.apache.struts2.convention.annotation.Result;

import fr.inra.agrosyst.api.entities.GrowingPlan;
import fr.inra.agrosyst.api.services.growingplan.GrowingPlanService;
import fr.inra.agrosyst.web.actions.AbstractAgrosystAction;

/**
 * Duplication unique de dispositif.
 * 
 * @author Eric Chatellier
 */
public class GrowingPlansDuplicate extends AbstractAgrosystAction {

    private static final long serialVersionUID = -4930761732959095035L;

    protected GrowingPlanService growingPlanService;

    protected String growingPlanIds;

    protected String duplicateDomainId;

    protected boolean duplicateGrowingSystems;

    /** Duplicated growing plan. */
    protected GrowingPlan growingPlan;

    public void setGrowingPlanService(GrowingPlanService growingPlanService) {
        this.growingPlanService = growingPlanService;
    }

    public void setGrowingPlanIds(String growingPlanIds) {
        this.growingPlanIds = growingPlanIds;
    }

    public void setDuplicateDomainId(String duplicateDomainId) {
        this.duplicateDomainId = duplicateDomainId;
    }

    public void setDuplicateGrowingSystems(boolean duplicateGrowingSystems) {
        this.duplicateGrowingSystems = duplicateGrowingSystems;
    }

    @Override
    @Action(results = {
            @Result(name = SUCCESS, type = "redirectAction", params = {"actionName", "growing-plans-edit!input", "growingPlanTopiaId", "${growingPlan.topiaId}"}),
            @Result(name = ERROR, type = "redirectAction", params = {"actionName", "growing-plans-list"})})
    public String execute() throws Exception {
        growingPlan = growingPlanService.duplicateGrowingPlan(growingPlanIds, duplicateDomainId, duplicateGrowingSystems);
        return SUCCESS;
    }
    
    public GrowingPlan getGrowingPlan() {
        return growingPlan;
    }
}

==> agrosyst-web-0.6.1-sources.jar: fr/inra/agrosyst/web/actions/growingplans/GrowingPlansDuplicate.java <==
package fr.inra.agrosyst.web.actions.growingplans;

/*
 * #%L
 * Agrosyst :: Web
 * $Id: GrowingPlansDuplicate.java 1551 2013-10-04 06:12:18Z echatellier $
 * $HeadURL: https://forge.codelutin.com/svn/agrosyst/tags/agrosyst-0.6.1/agrosyst-web/src/main/java/fr/inra/agrosyst/web/actions/growingplans/GrowingPlansDuplicate.java $
 * %%
 * Copyright (C) 2013 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import org.apache.struts2.convention.annotation.Action;
import org.apache.struts2.convention.annotation.Result;

import fr.inra.agrosyst.api.entities.GrowingPlan;
import fr.inra.agrosyst.api.services.growingplan.GrowingPlanService;
import fr.inra.agrosyst.web.actions.AbstractAgrosystAction;

/**
 * Duplication unique de dispositif.
 * 
 * @author Eric Chatellier
 */
public class GrowingPlansDuplicate extends AbstractAgrosystAction {

    private static final long serialVersionUID = -4930761732959095035L;

    protected GrowingPlanService growingPlanService;

    protected String growingPlanIds;

    protected String duplicateDomainId;

    protected boolean duplicateGrowingSystems;

    /** Duplicated growing plan. */
    protected GrowingPlan growingPlan;

    public void setGrowingPlanService(GrowingPlanService growingPlanService) {
        this.growingPlanService = growingPlanService;
    }

    public void setGrowingPlanIds(String growingPlanIds) {
        this.growingPlanIds = growingPlanIds;
    }

    public void setDuplicateDomainId(String duplicateDomainId) {
        this.duplicateDomainId = duplicateDomainId;
    }

    public void setDuplicateGrowingSystems(boolean duplicateGrowingSystems) {
        this.duplicateGrowingSystems = duplicateGrowingSystems;
    }

    @Override
    @Action(results = {
            @Result(name = SUCCESS, type = "redirectAction", params = {"actionName", "growing-plans-edit-input", "growingPlanTopiaId", "${growingPlan.topiaId}"}),
            @Result(name = ERROR, type = "redirectAction", params = {"actionName", "growing-plans-list"})})
    public String execute() throws Exception {
        growingPlan = growingPlanService.duplicateGrowingPlan(growingPlanIds, duplicateDomainId, duplicateGrowingSystems);
        return SUCCESS;
    }
    
    public GrowingPlan getGrowingPlan() {
        return growingPlan;
    }
}
